@@ -14,6 +14,13 @@
 
 import unittest
 
+import mock
+
+
+def _make_credentials():
+    import google.auth.credentials
+    return mock.Mock(spec=google.auth.credentials.Credentials)
+
 
 class TestMIMEApplicationHTTP(unittest.TestCase):
 
@@ -89,7 +96,7 @@ class TestBatch(unittest.TestCase):
     def test_current(self):
         from google.cloud.storage.client import Client
         project = 'PROJECT'
-        credentials = _Credentials()
+        credentials = _make_credentials()
         client = Client(project=project, credentials=credentials)
         batch1 = self._make_one(client)
         self.assertIsNone(batch1.current())
@@ -378,7 +385,7 @@ class TestBatch(unittest.TestCase):
         expected['content-type'] = 'multipart/mixed; boundary="DEADBEEF="'
         http = _HTTP((expected, _THREE_PART_MIME_RESPONSE))
         project = 'PROJECT'
-        credentials = _Credentials()
+        credentials = _make_credentials()
         client = Client(project=project, credentials=credentials)
         client._base_connection._http = http
 
@@ -414,7 +421,7 @@ class TestBatch(unittest.TestCase):
         http = _HTTP()
         connection = _Connection(http=http)
         project = 'PROJECT'
-        credentials = _Credentials()
+        credentials = _make_credentials()
         client = Client(project=project, credentials=credentials)
         client._base_connection = connection
 
@@ -599,16 +606,3 @@ class _Client(object):
 
     def __init__(self, connection):
         self._base_connection = connection
-
-
-class _Credentials(object):
-
-    _scopes = None
-
-    @staticmethod
-    def create_scoped_required():
-        return True
-
-    def create_scoped(self, scope):
-        self._scopes = scope
-        return self
