@@ -15,79 +15,9 @@
 import unittest
 
 
-class Test__BlobIterator(unittest.TestCase):
-
-    def _getTargetClass(self):
-        from google.cloud.storage.bucket import _BlobIterator
-        return _BlobIterator
-
-    def _makeOne(self, *args, **kw):
-        return self._getTargetClass()(*args, **kw)
-
-    def test_ctor(self):
-        connection = _Connection()
-        client = _Client(connection)
-        bucket = _Bucket()
-        iterator = self._makeOne(bucket, client=client)
-        self.assertIs(iterator.bucket, bucket)
-        self.assertIs(iterator.client, client)
-        self.assertEqual(iterator.path, '%s/o' % bucket.path)
-        self.assertEqual(iterator.page_number, 0)
-        self.assertIsNone(iterator.next_page_token)
-        self.assertEqual(iterator.prefixes, set())
-
-    def test_get_items_from_response_empty(self):
-        connection = _Connection()
-        client = _Client(connection)
-        bucket = _Bucket()
-        iterator = self._makeOne(bucket, client=client)
-        blobs = list(iterator.get_items_from_response({}))
-        self.assertEqual(blobs, [])
-        self.assertEqual(iterator.prefixes, set())
-
-    def test_get_items_from_response_non_empty(self):
-        from google.cloud.storage.blob import Blob
-        BLOB_NAME = 'blob-name'
-        response = {'items': [{'name': BLOB_NAME}], 'prefixes': ['foo']}
-        connection = _Connection()
-        client = _Client(connection)
-        bucket = _Bucket()
-        iterator = self._makeOne(bucket, client=client)
-        blobs = list(iterator.get_items_from_response(response))
-        self.assertEqual(len(blobs), 1)
-        blob = blobs[0]
-        self.assertIsInstance(blob, Blob)
-        self.assertEqual(blob.name, BLOB_NAME)
-        self.assertEqual(iterator.prefixes, set(['foo']))
-
-    def test_get_items_from_response_cumulative_prefixes(self):
-        from google.cloud.storage.blob import Blob
-        BLOB_NAME = 'blob-name1'
-        response1 = {'items': [{'name': BLOB_NAME}], 'prefixes': ['foo']}
-        response2 = {
-            'items': [],
-            'prefixes': ['foo', 'bar'],
-        }
-        connection = _Connection()
-        client = _Client(connection)
-        bucket = _Bucket()
-        iterator = self._makeOne(bucket, client=client)
-        # Parse first response.
-        blobs = list(iterator.get_items_from_response(response1))
-        self.assertEqual(len(blobs), 1)
-        blob = blobs[0]
-        self.assertIsInstance(blob, Blob)
-        self.assertEqual(blob.name, BLOB_NAME)
-        self.assertEqual(iterator.prefixes, set(['foo']))
-        # Parse second response.
-        blobs = list(iterator.get_items_from_response(response2))
-        self.assertEqual(len(blobs), 0)
-        self.assertEqual(iterator.prefixes, set(['foo', 'bar']))
-
-
 class Test_Bucket(unittest.TestCase):
 
-    def _makeOne(self, client=None, name=None, properties=None):
+    def _make_one(self, client=None, name=None, properties=None):
         from google.cloud.storage.bucket import Bucket
         if client is None:
             connection = _Connection()
@@ -99,7 +29,7 @@ class Test_Bucket(unittest.TestCase):
     def test_ctor(self):
         NAME = 'name'
         properties = {'key': 'value'}
-        bucket = self._makeOne(name=NAME, properties=properties)
+        bucket = self._make_one(name=NAME, properties=properties)
         self.assertEqual(bucket.name, NAME)
         self.assertEqual(bucket._properties, properties)
         self.assertFalse(bucket._acl.loaded)
@@ -113,14 +43,17 @@ class Test_Bucket(unittest.TestCase):
         BUCKET_NAME = 'BUCKET_NAME'
         BLOB_NAME = 'BLOB_NAME'
         CHUNK_SIZE = 1024 * 1024
+        KEY = b'01234567890123456789012345678901'  # 32 bytes
 
-        bucket = self._makeOne(name=BUCKET_NAME)
-        blob = bucket.blob(BLOB_NAME, chunk_size=CHUNK_SIZE)
+        bucket = self._make_one(name=BUCKET_NAME)
+        blob = bucket.blob(
+            BLOB_NAME, chunk_size=CHUNK_SIZE, encryption_key=KEY)
         self.assertIsInstance(blob, Blob)
         self.assertIs(blob.bucket, bucket)
         self.assertIs(blob.client, bucket.client)
         self.assertEqual(blob.name, BLOB_NAME)
         self.assertEqual(blob.chunk_size, CHUNK_SIZE)
+        self.assertEqual(blob._encryption_key, KEY)
 
     def test_exists_miss(self):
         from google.cloud.exceptions import NotFound
@@ -135,7 +68,7 @@ class Test_Bucket(unittest.TestCase):
                 raise NotFound(args)
 
         BUCKET_NAME = 'bucket-name'
-        bucket = self._makeOne(name=BUCKET_NAME)
+        bucket = self._make_one(name=BUCKET_NAME)
         client = _Client(_FakeConnection)
         self.assertFalse(bucket.exists(client=client))
         expected_called_kwargs = {
@@ -161,7 +94,7 @@ class Test_Bucket(unittest.TestCase):
                 return object()
 
         BUCKET_NAME = 'bucket-name'
-        bucket = self._makeOne(name=BUCKET_NAME)
+        bucket = self._make_one(name=BUCKET_NAME)
         client = _Client(_FakeConnection)
         self.assertTrue(bucket.exists(client=client))
         expected_called_kwargs = {
@@ -181,7 +114,7 @@ class Test_Bucket(unittest.TestCase):
         connection = _Connection(DATA)
         PROJECT = 'PROJECT'
         client = _Client(connection, project=PROJECT)
-        bucket = self._makeOne(client=client, name=BUCKET_NAME)
+        bucket = self._make_one(client=client, name=BUCKET_NAME)
         bucket.create()
 
         kw, = connection._requested
@@ -215,7 +148,7 @@ class Test_Bucket(unittest.TestCase):
         }
         connection = _Connection(DATA)
         client = _Client(connection, project=PROJECT)
-        bucket = self._makeOne(client=client, name=BUCKET_NAME)
+        bucket = self._make_one(client=client, name=BUCKET_NAME)
         bucket.cors = CORS
         bucket.lifecycle_rules = LIFECYCLE_RULES
         bucket.location = LOCATION
@@ -231,25 +164,25 @@ class Test_Bucket(unittest.TestCase):
 
     def test_acl_property(self):
         from google.cloud.storage.acl import BucketACL
-        bucket = self._makeOne()
+        bucket = self._make_one()
         acl = bucket.acl
         self.assertIsInstance(acl, BucketACL)
         self.assertIs(acl, bucket._acl)
 
     def test_default_object_acl_property(self):
         from google.cloud.storage.acl import DefaultObjectACL
-        bucket = self._makeOne()
+        bucket = self._make_one()
         acl = bucket.default_object_acl
         self.assertIsInstance(acl, DefaultObjectACL)
         self.assertIs(acl, bucket._default_object_acl)
 
     def test_path_no_name(self):
-        bucket = self._makeOne()
+        bucket = self._make_one()
         self.assertRaises(ValueError, getattr, bucket, 'path')
 
     def test_path_w_name(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         self.assertEqual(bucket.path, '/b/%s' % NAME)
 
     def test_get_blob_miss(self):
@@ -257,7 +190,7 @@ class Test_Bucket(unittest.TestCase):
         NONESUCH = 'nonesuch'
         connection = _Connection()
         client = _Client(connection)
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         result = bucket.get_blob(NONESUCH, client=client)
         self.assertIsNone(result)
         kw, = connection._requested
@@ -269,7 +202,7 @@ class Test_Bucket(unittest.TestCase):
         BLOB_NAME = 'blob-name'
         connection = _Connection({'name': BLOB_NAME})
         client = _Client(connection)
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         blob = bucket.get_blob(BLOB_NAME, client=client)
         self.assertIs(blob.bucket, bucket)
         self.assertEqual(blob.name, BLOB_NAME)
@@ -281,7 +214,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         connection = _Connection({'items': []})
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         iterator = bucket.list_blobs()
         blobs = list(iterator)
         self.assertEqual(blobs, [])
@@ -310,7 +243,7 @@ class Test_Bucket(unittest.TestCase):
         }
         connection = _Connection({'items': []})
         client = _Client(connection)
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         iterator = bucket.list_blobs(
             max_results=MAX_RESULTS,
             page_token=PAGE_TOKEN,
@@ -332,7 +265,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         connection = _Connection({'items': []})
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         iterator = bucket.list_blobs()
         blobs = list(iterator)
         self.assertEqual(blobs, [])
@@ -346,7 +279,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         connection = _Connection()
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         self.assertRaises(NotFound, bucket.delete)
         expected_cw = [{
             'method': 'DELETE',
@@ -361,7 +294,7 @@ class Test_Bucket(unittest.TestCase):
         connection = _Connection(GET_BLOBS_RESP)
         connection._delete_bucket = True
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         result = bucket.delete(force=True)
         self.assertIsNone(result)
         expected_cw = [{
@@ -386,7 +319,7 @@ class Test_Bucket(unittest.TestCase):
                                  DELETE_BLOB2_RESP)
         connection._delete_bucket = True
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         result = bucket.delete(force=True)
         self.assertIsNone(result)
         expected_cw = [{
@@ -404,7 +337,7 @@ class Test_Bucket(unittest.TestCase):
         connection = _Connection(GET_BLOBS_RESP)
         connection._delete_bucket = True
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         result = bucket.delete(force=True)
         self.assertIsNone(result)
         expected_cw = [{
@@ -427,7 +360,7 @@ class Test_Bucket(unittest.TestCase):
         connection = _Connection(GET_BLOBS_RESP)
         connection._delete_bucket = True
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
 
         # Make the Bucket refuse to delete with 2 objects.
         bucket._MAX_OBJECTS_FOR_ITERATION = 1
@@ -440,7 +373,7 @@ class Test_Bucket(unittest.TestCase):
         NONESUCH = 'nonesuch'
         connection = _Connection()
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         self.assertRaises(NotFound, bucket.delete_blob, NONESUCH)
         kw, = connection._requested
         self.assertEqual(kw['method'], 'DELETE')
@@ -451,7 +384,7 @@ class Test_Bucket(unittest.TestCase):
         BLOB_NAME = 'blob-name'
         connection = _Connection({})
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         result = bucket.delete_blob(BLOB_NAME)
         self.assertIsNone(result)
         kw, = connection._requested
@@ -462,7 +395,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         connection = _Connection()
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         bucket.delete_blobs([])
         self.assertEqual(connection._requested, [])
 
@@ -471,7 +404,7 @@ class Test_Bucket(unittest.TestCase):
         BLOB_NAME = 'blob-name'
         connection = _Connection({})
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         bucket.delete_blobs([BLOB_NAME])
         kw = connection._requested
         self.assertEqual(len(kw), 1)
@@ -485,7 +418,7 @@ class Test_Bucket(unittest.TestCase):
         NONESUCH = 'nonesuch'
         connection = _Connection({})
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         self.assertRaises(NotFound, bucket.delete_blobs, [BLOB_NAME, NONESUCH])
         kw = connection._requested
         self.assertEqual(len(kw), 2)
@@ -500,7 +433,7 @@ class Test_Bucket(unittest.TestCase):
         NONESUCH = 'nonesuch'
         connection = _Connection({})
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         errors = []
         bucket.delete_blobs([BLOB_NAME, NONESUCH], errors.append)
         self.assertEqual(errors, [NONESUCH])
@@ -522,8 +455,8 @@ class Test_Bucket(unittest.TestCase):
 
         connection = _Connection({})
         client = _Client(connection)
-        source = self._makeOne(client=client, name=SOURCE)
-        dest = self._makeOne(client=client, name=DEST)
+        source = self._make_one(client=client, name=SOURCE)
+        dest = self._make_one(client=client, name=DEST)
         blob = _Blob()
         new_blob = source.copy_blob(blob, dest)
         self.assertIs(new_blob.bucket, dest)
@@ -551,8 +484,8 @@ class Test_Bucket(unittest.TestCase):
 
         connection = _Connection({}, {})
         client = _Client(connection)
-        source = self._makeOne(client=client, name=SOURCE)
-        dest = self._makeOne(client=client, name=DEST)
+        source = self._make_one(client=client, name=SOURCE)
+        dest = self._make_one(client=client, name=DEST)
         blob = _Blob()
         new_blob = source.copy_blob(blob, dest, NEW_NAME, client=client,
                                     preserve_acl=False)
@@ -578,8 +511,8 @@ class Test_Bucket(unittest.TestCase):
 
         connection = _Connection({})
         client = _Client(connection)
-        source = self._makeOne(client=client, name=SOURCE)
-        dest = self._makeOne(client=client, name=DEST)
+        source = self._make_one(client=client, name=SOURCE)
+        dest = self._make_one(client=client, name=DEST)
         blob = _Blob()
         new_blob = source.copy_blob(blob, dest, NEW_NAME)
         self.assertIs(new_blob.bucket, dest)
@@ -598,7 +531,7 @@ class Test_Bucket(unittest.TestCase):
         DATA = {'name': NEW_BLOB_NAME}
         connection = _Connection(DATA)
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=BUCKET_NAME)
+        bucket = self._make_one(client=client, name=BUCKET_NAME)
 
         class _Blob(object):
 
@@ -619,24 +552,24 @@ class Test_Bucket(unittest.TestCase):
     def test_etag(self):
         ETAG = 'ETAG'
         properties = {'etag': ETAG}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.etag, ETAG)
 
     def test_id(self):
         ID = 'ID'
         properties = {'id': ID}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.id, ID)
 
     def test_location_getter(self):
         NAME = 'name'
         before = {'location': 'AS'}
-        bucket = self._makeOne(name=NAME, properties=before)
+        bucket = self._make_one(name=NAME, properties=before)
         self.assertEqual(bucket.location, 'AS')
 
     def test_location_setter(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         self.assertIsNone(bucket.location)
         bucket.location = 'AS'
         self.assertEqual(bucket.location, 'AS')
@@ -647,7 +580,7 @@ class Test_Bucket(unittest.TestCase):
         LC_RULE = {'action': {'type': 'Delete'}, 'condition': {'age': 42}}
         rules = [LC_RULE]
         properties = {'lifecycle': {'rule': rules}}
-        bucket = self._makeOne(name=NAME, properties=properties)
+        bucket = self._make_one(name=NAME, properties=properties)
         self.assertEqual(bucket.lifecycle_rules, rules)
         # Make sure it's a copy
         self.assertIsNot(bucket.lifecycle_rules, rules)
@@ -656,7 +589,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         LC_RULE = {'action': {'type': 'Delete'}, 'condition': {'age': 42}}
         rules = [LC_RULE]
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         self.assertEqual(bucket.lifecycle_rules, [])
         bucket.lifecycle_rules = rules
         self.assertEqual(bucket.lifecycle_rules, rules)
@@ -671,7 +604,7 @@ class Test_Bucket(unittest.TestCase):
             'responseHeader': ['Content-Type'],
         }
         properties = {'cors': [CORS_ENTRY, {}]}
-        bucket = self._makeOne(name=NAME, properties=properties)
+        bucket = self._make_one(name=NAME, properties=properties)
         entries = bucket.cors
         self.assertEqual(len(entries), 2)
         self.assertEqual(entries[0], CORS_ENTRY)
@@ -687,7 +620,7 @@ class Test_Bucket(unittest.TestCase):
             'origin': ['127.0.0.1'],
             'responseHeader': ['Content-Type'],
         }
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
 
         self.assertEqual(bucket.cors, [])
         bucket.cors = [CORS_ENTRY]
@@ -704,7 +637,7 @@ class Test_Bucket(unittest.TestCase):
                 'logObjectPrefix': LOG_PREFIX,
             },
         }
-        bucket = self._makeOne(name=NAME, properties=before)
+        bucket = self._make_one(name=NAME, properties=before)
         info = bucket.get_logging()
         self.assertEqual(info['logBucket'], LOG_BUCKET)
         self.assertEqual(info['logObjectPrefix'], LOG_PREFIX)
@@ -713,7 +646,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         LOG_BUCKET = 'logs'
         before = {'logging': None}
-        bucket = self._makeOne(name=NAME, properties=before)
+        bucket = self._make_one(name=NAME, properties=before)
         self.assertIsNone(bucket.get_logging())
         bucket.enable_logging(LOG_BUCKET)
         info = bucket.get_logging()
@@ -725,7 +658,7 @@ class Test_Bucket(unittest.TestCase):
         LOG_BUCKET = 'logs'
         LOG_PFX = 'pfx'
         before = {'logging': None}
-        bucket = self._makeOne(name=NAME, properties=before)
+        bucket = self._make_one(name=NAME, properties=before)
         self.assertIsNone(bucket.get_logging())
         bucket.enable_logging(LOG_BUCKET, LOG_PFX)
         info = bucket.get_logging()
@@ -735,7 +668,7 @@ class Test_Bucket(unittest.TestCase):
     def test_disable_logging(self):
         NAME = 'name'
         before = {'logging': {'logBucket': 'logs', 'logObjectPrefix': 'pfx'}}
-        bucket = self._makeOne(name=NAME, properties=before)
+        bucket = self._make_one(name=NAME, properties=before)
         self.assertIsNotNone(bucket.get_logging())
         bucket.disable_logging()
         self.assertIsNone(bucket.get_logging())
@@ -743,23 +676,23 @@ class Test_Bucket(unittest.TestCase):
     def test_metageneration(self):
         METAGENERATION = 42
         properties = {'metageneration': METAGENERATION}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.metageneration, METAGENERATION)
 
     def test_metageneration_unset(self):
-        bucket = self._makeOne()
+        bucket = self._make_one()
         self.assertIsNone(bucket.metageneration)
 
     def test_metageneration_string_val(self):
         METAGENERATION = 42
         properties = {'metageneration': str(METAGENERATION)}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.metageneration, METAGENERATION)
 
     def test_owner(self):
         OWNER = {'entity': 'project-owner-12345', 'entityId': '23456'}
         properties = {'owner': OWNER}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         owner = bucket.owner
         self.assertEqual(owner['entity'], 'project-owner-12345')
         self.assertEqual(owner['entityId'], '23456')
@@ -767,55 +700,76 @@ class Test_Bucket(unittest.TestCase):
     def test_project_number(self):
         PROJECT_NUMBER = 12345
         properties = {'projectNumber': PROJECT_NUMBER}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.project_number, PROJECT_NUMBER)
 
     def test_project_number_unset(self):
-        bucket = self._makeOne()
+        bucket = self._make_one()
         self.assertIsNone(bucket.project_number)
 
     def test_project_number_string_val(self):
         PROJECT_NUMBER = 12345
         properties = {'projectNumber': str(PROJECT_NUMBER)}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.project_number, PROJECT_NUMBER)
 
     def test_self_link(self):
         SELF_LINK = 'http://example.com/self/'
         properties = {'selfLink': SELF_LINK}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.self_link, SELF_LINK)
 
     def test_storage_class_getter(self):
         STORAGE_CLASS = 'http://example.com/self/'
         properties = {'storageClass': STORAGE_CLASS}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.storage_class, STORAGE_CLASS)
 
     def test_storage_class_setter_invalid(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         with self.assertRaises(ValueError):
             bucket.storage_class = 'BOGUS'
         self.assertFalse('storageClass' in bucket._changes)
 
     def test_storage_class_setter_STANDARD(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         bucket.storage_class = 'STANDARD'
         self.assertEqual(bucket.storage_class, 'STANDARD')
         self.assertTrue('storageClass' in bucket._changes)
 
     def test_storage_class_setter_NEARLINE(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         bucket.storage_class = 'NEARLINE'
         self.assertEqual(bucket.storage_class, 'NEARLINE')
         self.assertTrue('storageClass' in bucket._changes)
 
+    def test_storage_class_setter_COLDLINE(self):
+        NAME = 'name'
+        bucket = self._make_one(name=NAME)
+        bucket.storage_class = 'COLDLINE'
+        self.assertEqual(bucket.storage_class, 'COLDLINE')
+        self.assertTrue('storageClass' in bucket._changes)
+
+    def test_storage_class_setter_MULTI_REGIONAL(self):
+        NAME = 'name'
+        bucket = self._make_one(name=NAME)
+        bucket.storage_class = 'MULTI_REGIONAL'
+        self.assertEqual(bucket.storage_class, 'MULTI_REGIONAL')
+        self.assertTrue('storageClass' in bucket._changes)
+
+    def test_storage_class_setter_REGIONAL(self):
+        NAME = 'name'
+        bucket = self._make_one(name=NAME)
+        bucket.storage_class = 'REGIONAL'
+        self.assertEqual(bucket.storage_class, 'REGIONAL')
+        self.assertTrue('storageClass' in bucket._changes)
+
     def test_storage_class_setter_DURABLE_REDUCED_AVAILABILITY(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         bucket.storage_class = 'DURABLE_REDUCED_AVAILABILITY'
         self.assertEqual(bucket.storage_class, 'DURABLE_REDUCED_AVAILABILITY')
         self.assertTrue('storageClass' in bucket._changes)
@@ -827,27 +781,27 @@ class Test_Bucket(unittest.TestCase):
         TIMESTAMP = datetime.datetime(2014, 11, 5, 20, 34, 37, tzinfo=UTC)
         TIME_CREATED = TIMESTAMP.strftime(_RFC3339_MICROS)
         properties = {'timeCreated': TIME_CREATED}
-        bucket = self._makeOne(properties=properties)
+        bucket = self._make_one(properties=properties)
         self.assertEqual(bucket.time_created, TIMESTAMP)
 
     def test_time_created_unset(self):
-        bucket = self._makeOne()
+        bucket = self._make_one()
         self.assertIsNone(bucket.time_created)
 
     def test_versioning_enabled_getter_missing(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         self.assertEqual(bucket.versioning_enabled, False)
 
     def test_versioning_enabled_getter(self):
         NAME = 'name'
         before = {'versioning': {'enabled': True}}
-        bucket = self._makeOne(name=NAME, properties=before)
+        bucket = self._make_one(name=NAME, properties=before)
         self.assertEqual(bucket.versioning_enabled, True)
 
     def test_versioning_enabled_setter(self):
         NAME = 'name'
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         self.assertFalse(bucket.versioning_enabled)
         bucket.versioning_enabled = True
         self.assertTrue(bucket.versioning_enabled)
@@ -856,7 +810,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         UNSET = {'website': {'mainPageSuffix': None,
                              'notFoundPage': None}}
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         bucket.configure_website()
         self.assertEqual(bucket._properties, UNSET)
 
@@ -864,7 +818,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         WEBSITE_VAL = {'website': {'mainPageSuffix': 'html',
                                    'notFoundPage': '404.html'}}
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         bucket.configure_website('html', '404.html')
         self.assertEqual(bucket._properties, WEBSITE_VAL)
 
@@ -872,7 +826,7 @@ class Test_Bucket(unittest.TestCase):
         NAME = 'name'
         UNSET = {'website': {'mainPageSuffix': None,
                              'notFoundPage': None}}
-        bucket = self._makeOne(name=NAME)
+        bucket = self._make_one(name=NAME)
         bucket.disable_website()
         self.assertEqual(bucket._properties, UNSET)
 
@@ -883,7 +837,7 @@ class Test_Bucket(unittest.TestCase):
         after = {'acl': permissive, 'defaultObjectAcl': []}
         connection = _Connection(after)
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         bucket.acl.loaded = True
         bucket.default_object_acl.loaded = True
         bucket.make_public()
@@ -911,7 +865,7 @@ class Test_Bucket(unittest.TestCase):
             # to consume.
             connection = _Connection(after1, after1, after2)
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         bucket.acl.loaded = True
         bucket.default_object_acl.loaded = default_object_acl_loaded
         bucket.make_public(future=True)
@@ -939,8 +893,9 @@ class Test_Bucket(unittest.TestCase):
         self._make_public_w_future_helper(default_object_acl_loaded=False)
 
     def test_make_public_recursive(self):
+        import mock
         from google.cloud.storage.acl import _ACLEntity
-        from google.cloud.storage.bucket import _BlobIterator
+
         _saved = []
 
         class _Blob(object):
@@ -965,10 +920,8 @@ class Test_Bucket(unittest.TestCase):
                 _saved.append(
                     (self._bucket, self._name, self._granted, client))
 
-        class _Iterator(_BlobIterator):
-            def get_items_from_response(self, response):
-                for item in response.get('items', []):
-                    yield _Blob(self.bucket, item['name'])
+        def item_to_blob(self, item):
+            return _Blob(self.bucket, item['name'])
 
         NAME = 'name'
         BLOB_NAME = 'blob-name'
@@ -976,11 +929,13 @@ class Test_Bucket(unittest.TestCase):
         after = {'acl': permissive, 'defaultObjectAcl': []}
         connection = _Connection(after, {'items': [{'name': BLOB_NAME}]})
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         bucket.acl.loaded = True
         bucket.default_object_acl.loaded = True
-        bucket._iterator_class = _Iterator
-        bucket.make_public(recursive=True)
+
+        with mock.patch('google.cloud.storage.bucket._item_to_blob',
+                        new=item_to_blob):
+            bucket.make_public(recursive=True)
         self.assertEqual(list(bucket.acl), permissive)
         self.assertEqual(list(bucket.default_object_acl), [])
         self.assertEqual(_saved, [(bucket, BLOB_NAME, True, None)])
@@ -1013,7 +968,7 @@ class Test_Bucket(unittest.TestCase):
         }
         connection = _Connection(AFTER, GET_BLOBS_RESP)
         client = _Client(connection)
-        bucket = self._makeOne(client=client, name=NAME)
+        bucket = self._make_one(client=client, name=NAME)
         bucket.acl.loaded = True
         bucket.default_object_acl.loaded = True
 
@@ -1021,6 +976,88 @@ class Test_Bucket(unittest.TestCase):
         bucket._MAX_OBJECTS_FOR_ITERATION = 1
         self.assertRaises(ValueError, bucket.make_public, recursive=True)
 
+    def test_page_empty_response(self):
+        from google.cloud.iterator import Page
+
+        connection = _Connection()
+        client = _Client(connection)
+        name = 'name'
+        bucket = self._make_one(client=client, name=name)
+        iterator = bucket.list_blobs()
+        page = Page(iterator, (), None)
+        iterator._page = page
+        blobs = list(page)
+        self.assertEqual(blobs, [])
+        self.assertEqual(iterator.prefixes, set())
+
+    def test_page_non_empty_response(self):
+        import six
+        from google.cloud.storage.blob import Blob
+
+        blob_name = 'blob-name'
+        response = {'items': [{'name': blob_name}], 'prefixes': ['foo']}
+        connection = _Connection()
+        client = _Client(connection)
+        name = 'name'
+        bucket = self._make_one(client=client, name=name)
+
+        def dummy_response():
+            return response
+
+        iterator = bucket.list_blobs()
+        iterator._get_next_page_response = dummy_response
+
+        page = six.next(iterator.pages)
+        self.assertEqual(page.prefixes, ('foo',))
+        self.assertEqual(page.num_items, 1)
+        blob = six.next(page)
+        self.assertEqual(page.remaining, 0)
+        self.assertIsInstance(blob, Blob)
+        self.assertEqual(blob.name, blob_name)
+        self.assertEqual(iterator.prefixes, set(['foo']))
+
+    def test_cumulative_prefixes(self):
+        import six
+        from google.cloud.storage.blob import Blob
+
+        BLOB_NAME = 'blob-name1'
+        response1 = {
+            'items': [{'name': BLOB_NAME}],
+            'prefixes': ['foo'],
+            'nextPageToken': 's39rmf9',
+        }
+        response2 = {
+            'items': [],
+            'prefixes': ['bar'],
+        }
+        connection = _Connection()
+        client = _Client(connection)
+        name = 'name'
+        bucket = self._make_one(client=client, name=name)
+        responses = [response1, response2]
+
+        def dummy_response():
+            return responses.pop(0)
+
+        iterator = bucket.list_blobs()
+        iterator._get_next_page_response = dummy_response
+
+        # Parse first response.
+        pages_iter = iterator.pages
+        page1 = six.next(pages_iter)
+        self.assertEqual(page1.prefixes, ('foo',))
+        self.assertEqual(page1.num_items, 1)
+        blob = six.next(page1)
+        self.assertEqual(page1.remaining, 0)
+        self.assertIsInstance(blob, Blob)
+        self.assertEqual(blob.name, BLOB_NAME)
+        self.assertEqual(iterator.prefixes, set(['foo']))
+        # Parse second response.
+        page2 = six.next(pages_iter)
+        self.assertEqual(page2.prefixes, ('bar',))
+        self.assertEqual(page2.num_items, 0)
+        self.assertEqual(iterator.prefixes, set(['foo', 'bar']))
+
 
 class _Connection(object):
     _delete_bucket = False
@@ -1056,16 +1093,8 @@ class _Connection(object):
             return response
 
 
-class _Bucket(object):
-    path = '/b/name'
-    name = 'name'
-
-    def __init__(self, client=None):
-        self.client = client
-
-
 class _Client(object):
 
     def __init__(self, connection, project=None):
-        self.connection = connection
+        self._connection = connection
         self.project = project
