@@ -14,6 +14,13 @@
 
 import unittest
 
+import mock
+
+
+def _make_credentials():
+    import google.auth.credentials
+    return mock.Mock(spec=google.auth.credentials.Credentials)
+
 
 class TestClient(unittest.TestCase):
 
@@ -29,7 +36,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage._http import Connection
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         self.assertEqual(client.project, PROJECT)
@@ -42,7 +49,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage.batch import Batch
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         batch1 = Batch(client)
@@ -61,7 +68,7 @@ class TestClient(unittest.TestCase):
 
     def test__connection_setter(self):
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         client._base_connection = None  # Unset the value from the constructor
         client._connection = connection = object()
@@ -69,13 +76,13 @@ class TestClient(unittest.TestCase):
 
     def test__connection_setter_when_set(self):
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         self.assertRaises(ValueError, setattr, client, '_connection', None)
 
     def test__connection_getter_no_batch(self):
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         self.assertIs(client._connection, client._base_connection)
         self.assertIsNone(client.current_batch)
@@ -83,7 +90,7 @@ class TestClient(unittest.TestCase):
     def test__connection_getter_with_batch(self):
         from google.cloud.storage.batch import Batch
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         batch = Batch(client)
         client._push_batch(batch)
@@ -95,7 +102,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage.bucket import Bucket
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         BUCKET_NAME = 'BUCKET_NAME'
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
@@ -108,7 +115,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage.batch import Batch
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         batch = client.batch()
@@ -119,7 +126,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.exceptions import NotFound
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         NONESUCH = 'nonesuch'
@@ -142,7 +149,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage.bucket import Bucket
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         BLOB_NAME = 'blob-name'
@@ -166,7 +173,7 @@ class TestClient(unittest.TestCase):
 
     def test_lookup_bucket_miss(self):
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         NONESUCH = 'nonesuch'
@@ -190,7 +197,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage.bucket import Bucket
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         BLOB_NAME = 'blob-name'
@@ -216,7 +223,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.exceptions import Conflict
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         BLOB_NAME = 'blob-name'
@@ -239,7 +246,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage.bucket import Bucket
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         BLOB_NAME = 'blob-name'
@@ -265,7 +272,7 @@ class TestClient(unittest.TestCase):
         from six.moves.urllib.parse import urlparse
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         EXPECTED_QUERY = {
@@ -297,7 +304,7 @@ class TestClient(unittest.TestCase):
         from six.moves.urllib.parse import urlencode
         from six.moves.urllib.parse import urlparse
         PROJECT = 'PROJECT'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         BUCKET_NAME = 'bucket-name'
@@ -326,7 +333,7 @@ class TestClient(unittest.TestCase):
         from six.moves.urllib.parse import urlparse
 
         PROJECT = 'foo-bar'
-        CREDENTIALS = _Credentials()
+        CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         MAX_RESULTS = 10
@@ -374,7 +381,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.iterator import Page
 
         project = 'PROJECT'
-        credentials = _Credentials()
+        credentials = _make_credentials()
         client = self._make_one(project=project, credentials=credentials)
         iterator = client.list_buckets()
         page = Page(iterator, (), None)
@@ -386,7 +393,7 @@ class TestClient(unittest.TestCase):
         from google.cloud.storage.bucket import Bucket
 
         project = 'PROJECT'
-        credentials = _Credentials()
+        credentials = _make_credentials()
         client = self._make_one(project=project, credentials=credentials)
 
         blob_name = 'blob-name'
@@ -406,19 +413,6 @@ class TestClient(unittest.TestCase):
         self.assertEqual(bucket.name, blob_name)
 
 
-class _Credentials(object):
-
-    _scopes = None
-
-    @staticmethod
-    def create_scoped_required():
-        return True
-
-    def create_scoped(self, scope):
-        self._scopes = scope
-        return self
-
-
 class _Http(object):
 
     _called_with = None
